@@ -106,7 +106,7 @@ namespace Docky.Windowing
 		
 		static IEnumerable<string> PrefixStrings {
 			get {
-				yield return "gksu";
+				yield return "gksu(do)?";
 				yield return "sudo";
 				yield return "java";
 				yield return "mono";
@@ -125,11 +125,11 @@ namespace Docky.Windowing
 		static IEnumerable<string> SuffixStrings {
 			get {
 				// some wine apps are launched via a shell script that sets the proc name to "app.exe"
-				yield return ".exe";
-				// some apps have a script 'foo' which does 'exec foo-bin'
-				yield return "-bin";
+				yield return "\\.exe";
+				// some apps have a script 'foo' which does 'exec foo-bin' or 'exec foo.bin'
+				yield return "[.-]bin";
 				// some python apps have a script 'foo' for 'python foo.py'
-				yield return ".py";
+				yield return "\\.py";
 				// some apps append versions, such as '-1' or '-3.0'
 				yield return "(-)?\\d+(\\.\\d+)?";
 			}
@@ -297,14 +297,17 @@ namespace Docky.Windowing
 			
 			if (WindowIsOpenOffice (window))
 				SetupWindow (window);
-			
-			string file = window_to_desktop_files[window].FirstOrDefault ();
 
-			if (file == null)
-				file = "";
-			file = file.EndsWith (".desktop") ? file : null;
+			string homedir = Environment.GetFolderPath (Environment.SpecialFolder.Personal);
+			List<string> matches;
+			if (window_to_desktop_files.TryGetValue (window, out matches)) {
+				string useritem = matches.Find (item => item.StartsWith (homedir));
+				if (useritem != null)
+					return useritem;
+				return matches.FirstOrDefault ();
+ 			}
 			
-			return file;
+			return null;
 		}
 		
 		public bool WindowIsReadyForMatch (Wnck.Window window)
@@ -317,7 +320,7 @@ namespace Docky.Windowing
 			return win.EndsWith (".desktop");
 		}
 		
-		bool WindowIsOpenOffice (Wnck.Window window)
+		public bool WindowIsOpenOffice (Wnck.Window window)
 		{
 			return window.ClassGroup != null && window.ClassGroup.Name.ToLower ().StartsWith ("openoffice");
 		}
@@ -428,6 +431,8 @@ namespace Docky.Windowing
 								matched = true;
 							}
 						}
+						if (matched)
+							break;
 					}
 					// if we found a match, bail.
 					if (matched)
@@ -580,7 +585,10 @@ namespace Docky.Windowing
 						continue;
 					
 					string cls = item.GetString ("StartupWMClass").Trim ();
-					result [cls] = file;
+					// we only want exactly 1 launcher, and so if we already have one we use that
+					// otherwise it will prefer global over local launchers
+					if (!result.ContainsKey (cls))
+						result [cls] = file;
 				}
 			}
 			
@@ -603,11 +611,11 @@ namespace Docky.Windowing
 					string vexec = null;
 					
 					if (exec.Contains (' ') &&
-						(exec.StartsWith ("ooffice") || exec.StartsWith ("openoffice.org3") || exec.StartsWith ("soffice.bin"))) {
+						(exec.StartsWith ("ooffice") || exec.StartsWith ("openoffice") || exec.StartsWith ("soffice"))) {
 						vexec = "ooffice" + exec.Split (' ') [1];
 					// for wine apps
-					} else if ((exec.StartsWith ("env WINEPREFIX=") && exec.Contains (" wine ")) ||
-							exec.StartsWith ("wine ")) {
+					} else if ((exec.Contains ("env WINEPREFIX=") && exec.Contains (" wine ")) ||
+							exec.Contains ("wine ")) {
 						int startIndex = exec.IndexOf ("wine ") + 5; // length of 'wine '
 						// CommandLineForPid already splits based on \\ and takes the last entry, so do the same here
 						vexec = exec.Substring (startIndex).Split (new [] {@"\\"}, StringSplitOptions.RemoveEmptyEntries).Last ();
@@ -629,11 +637,17 @@ namespace Docky.Windowing
 						using (GLib.DataInputStream stream = new GLib.DataInputStream (launcher.Read (null))) {
 							ulong len;
 							string line;
-							while ((line = stream.ReadLine (out len, null)) != null) {
-								if (line.StartsWith ("exec")) {
-									execLine = line;
-									break;
+							try {
+								while ((line = stream.ReadLine (out len, null)) != null) {
+									if (line.StartsWith ("exec")) {
+										execLine = line;
+										break;
+									}
 								}
+							} catch (Exception e) {
+								Log<WindowMatcher>.Error (e.Message);
+								Log<WindowMatcher>.Error (e.StackTrace);
+								continue;
 							}
 						}
 		
