@@ -24,6 +24,7 @@ using System.Threading;
 using System.IO;
 
 using Mono.Unix;
+using NDesk.DBus;
 
 using Gdk;
 using Gtk;
@@ -71,6 +72,10 @@ namespace Docky
 			
 			// set process name
 			DockServices.System.SetProcessName ("docky");
+			if (CheckForInstance ()) {
+				Log.Error ("Another Docky instance was detected - exiting.");
+				return;
+			}
 			
 			// cache main thread
 			SystemService.MainThread = Thread.CurrentThread;
@@ -95,6 +100,11 @@ namespace Docky
 			Gnome.Vfs.Vfs.Shutdown ();
 		}
 		
+		static bool CheckForInstance ()
+		{
+			return Bus.Session.NameHasOwner ("org.gnome.Docky");
+		}
+		
 		static void CheckComposite ()
 		{
 			GLib.Timeout.Add (2000, delegate {
