@@ -48,6 +48,7 @@ namespace Docky.Interface
 		bool drag_disabled = false;
 		int marker = 0;
 		uint drag_hover_timer;
+		IDictionary<AbstractDockItem, int> original_item_pos = new Dictionary<AbstractDockItem, int> ();
 		
 		AbstractDockItem drag_item;
 		
@@ -179,6 +180,8 @@ namespace Docky.Interface
 		{
 			Owner.CursorTracker.RequestHighResolution (this);
 			InternalDragActive = true;
+			Keyboard.Grab (Owner.GdkWindow, true, Gtk.Global.CurrentEventTime);
+			drag_canceled = false;
 			
 			if (proxy_window != null) {
 				EnableDragTo ();
@@ -187,16 +190,21 @@ namespace Docky.Interface
 			
 			Gdk.Pixbuf pbuf;
 			drag_item = Owner.HoveredItem;
+			original_item_pos.Clear ();
 			
 			// If we are in Reposition Mode or over a non-draggable item
 			// dont drag it!
 			if (drag_item is INonPersistedItem || RepositionMode)
 				drag_item = null;
 			
-			if (drag_item != null)
+			if (drag_item != null) {
+				foreach (AbstractDockItem adi in ProviderForItem (drag_item).Items)
+					original_item_pos [adi] = adi.Position;
+				
 				pbuf = Owner.HoveredItem.IconSurface (new DockySurface (1, 1), Owner.ZoomedIconSize, Owner.IconSize, 0).LoadToPixbuf ();
-			else
+			} else {
 				pbuf = new Gdk.Pixbuf (Gdk.Colorspace.Rgb, true, 8, 1, 1);
+			}
 			
 			Gtk.Drag.SetIconPixbuf (args.Context, pbuf, pbuf.Width / 2, pbuf.Height / 2);
 			pbuf.Dispose ();
@@ -337,6 +345,8 @@ namespace Docky.Interface
 			ExternalDragActive = false;
 		}
 		
+		bool drag_canceled;
+		
 		/// <summary>
 		/// Emitted on the drag source when the drag finishes
 		/// </summary>
@@ -345,7 +355,7 @@ namespace Docky.Interface
 			if (RepositionMode)
 				Owner.CursorTracker.CursorPositionChanged -= HandleCursorPositionChanged;
 			
-			if (drag_item != null) {
+			if (!drag_canceled && drag_item != null) {
 				if (!Owner.DockHovered) {
 					// Remove from dock
 					AbstractDockItemProvider provider = ProviderForItem (drag_item);
@@ -379,6 +389,7 @@ namespace Docky.Interface
 			
 			InternalDragActive = false;
 			drag_item = null;
+			Keyboard.Ungrab (Gtk.Global.CurrentEventTime);
 			
 			Owner.AnimatedDraw ();
 			Owner.CursorTracker.CancelHighResolution (this);
@@ -397,7 +408,17 @@ namespace Docky.Interface
 		/// </summary>
 		void HandleDragFailed (object o, DragFailedArgs args)
 		{
-			args.RetVal = true;
+			drag_canceled = args.DragResult == DragResult.UserCancelled;
+			
+			if (drag_canceled) {
+				foreach (KeyValuePair<AbstractDockItem, int> kvp in original_item_pos)
+					kvp.Key.Position = kvp.Value;
+				
+				Owner.UpdateCollectionBuffer ();
+				Owner.Preferences.SyncPreferences ();
+			}
+			
+			args.RetVal = !drag_canceled;
 		}
 
 		/// <summary>
