@@ -1,5 +1,5 @@
 //  
-//  Copyright (C) 2009 Jason Smith, Robert Dyer, Chris Szikszoy
+//  Copyright (C) 2009-2010 Jason Smith, Robert Dyer, Chris Szikszoy
 // 
 //  This program is free software: you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -350,6 +350,9 @@ namespace Docky.Interface
 			
 			DefaultProvider.ItemsChanged += HandleDefaultProviderItemsChanged;
 			
+			if (FirstRun)
+				FirstRun = false;
+			
 			ShowAll ();
 		}
 
@@ -449,6 +452,14 @@ namespace Docky.Interface
 			if (WindowManager)
 				DefaultProvider.SetWindowManager ();
 			
+			// on first run, add default plugins to the dock
+			if (FirstRun) {
+				Log<DockPreferences>.Info ("Adding default plugins.");
+				foreach (AbstractDockItemProvider provider in PluginManager.ItemProviders)
+					item_providers.Add (provider);
+				SyncPlugins ();
+			}
+			
 			autohide_box.Active = (int) Autohide;
 			UpdateAutohideDescription ();
 			fade_on_hide_check.Sensitive = (int) Autohide > 0;
@@ -464,7 +475,6 @@ namespace Docky.Interface
 			threedee_check.Sensitive = Position == DockPosition.Bottom;
 			multiple_window_indicator_check.Active = IndicateMultipleWindows;
 			
-			
 			window_manager_check.Active = DefaultProvider.IsWindowManager;
 			DefaultProvider.WindowManagerChanged += delegate {
 				WindowManager = window_manager_check.Active = DefaultProvider.IsWindowManager;
@@ -533,8 +543,6 @@ namespace Docky.Interface
 					launcher_music,
 					launcher_im,
 				}.Where (s => !String.IsNullOrEmpty (s));
-				
-				FirstRun = false;
 			}
 			
 			foreach (string launcher in Launchers) {
