@@ -153,12 +153,19 @@ namespace GMail
 				if (DockServices.System.UseProxy)
 					request.Proxy = DockServices.System.Proxy;
 				
-				using (HttpWebResponse response = (HttpWebResponse)request.GetResponse ())
+				using (HttpWebResponse response = (HttpWebResponse) request.GetResponse ())
 					try { } finally {
 						response.Close ();
 					}
 			} catch (WebException e) {
-				if (e.Message.IndexOf ("401") != -1) return false;
+				if (e.Message.IndexOf ("401") != -1)
+					Log<GMailAtom>.Error ("Invalid username: {0}", e.Message);
+				else
+					Log<GMailAtom>.Error ("Network error: {0}", e.Message);
+				HttpWebResponse response = (HttpWebResponse) e.Response;
+				Log<GMailAtom>.Debug ("Response status: {0} - {1}", response.StatusCode, response.StatusDescription);
+				
+				return false;
 			} catch (Exception) { }
 			
 			return true;
@@ -219,8 +226,13 @@ namespace GMail
 						
 						UnreadMessage message = new UnreadMessage ();
 						message.Topic = HttpUtility.HtmlDecode (item.SelectSingleNode ("atom:title", nsmgr).InnerText);
-						message.FromName = HttpUtility.HtmlDecode (item.SelectSingleNode ("atom:author/atom:name", nsmgr).InnerText);
-						message.FromEmail = item.SelectSingleNode ("atom:author/atom:email", nsmgr).InnerText;
+						// apparently random mailing lists can have no author information - bug 595530
+						XmlNode from = item.SelectSingleNode ("atom:author/atom:name", nsmgr);
+						if (from != null)
+							message.FromName = HttpUtility.HtmlDecode (from.InnerText);
+						from = item.SelectSingleNode ("atom:author/atom:email", nsmgr);
+						if (from != null)
+							message.FromEmail = from.InnerText;
 						message.From = message.FromName + " <" + message.FromEmail + ">";
 						try {
 							message.SendDate = DateTime.Parse (item.SelectSingleNode ("atom:modified", nsmgr).InnerText);
@@ -256,15 +268,18 @@ namespace GMail
 					Gtk.Application.Invoke (delegate { OnGMailChecked (); });
 				} catch (ThreadAbortException) {
 					Log<GMailAtom>.Debug ("Stoping Atom thread");
-				} catch (NullReferenceException) {
+				} catch (NullReferenceException e) {
+					Log<GMailAtom>.Debug (e.Message);
 					Gtk.Application.Invoke (delegate {
 						OnGMailFailed (Catalog.GetString ("Feed Error"));
 					});
-				} catch (XmlException) {
+				} catch (XmlException e) {
+					Log<GMailAtom>.Error ("Error parsing XML: {0}", e.Message);
 					Gtk.Application.Invoke (delegate {
 						OnGMailFailed (Catalog.GetString ("Feed Error"));
 					});
 				} catch (WebException e) {
+					Log<GMailAtom>.Error ("Network error: {0}", e.Message);
 					if (e.Message.IndexOf ("401") != -1)
 						Gtk.Application.Invoke (delegate {
 							OnGMailFailed (Catalog.GetString ("Invalid Username"));
@@ -273,12 +288,14 @@ namespace GMail
 						Gtk.Application.Invoke (delegate {
 							OnGMailFailed (Catalog.GetString ("Network Error"));
 						});
+					HttpWebResponse response = (HttpWebResponse) e.Response;
+					Log<GMailAtom>.Debug ("Response status: {0} - {1}", response.StatusCode, response.StatusDescription);
 				} catch (ObjectDisposedException) {
 					Gtk.Application.Invoke (delegate {
 						OnGMailFailed (Catalog.GetString ("Network Error"));
 					});
 				} catch (Exception e) {
-					Log<GMailAtom>.Error (e.ToString ());
+					Log<GMailAtom>.Error (e.Message);
 					Gtk.Application.Invoke (delegate {
 						OnGMailFailed (Catalog.GetString ("General Error"));
 					});
