@@ -114,17 +114,19 @@ namespace RecentDocuments
 		void UpdateInfo ()
 		{
 			lock (RecentDocs) {
-				if (RecentDocs.Count() == 0) {
+				if (RecentDocs.Count() == 0)
 					CurrentFile = null;
-					return;
-				}
-				
-				if (CurrentFile == null || RecentDocs.IndexOf (CurrentFile) == -1)
+				else if (CurrentFile != null && RecentDocs.IndexOf (CurrentFile) == -1)
 					CurrentFile = RecentDocs.First ();
 			}
 			
-			Icon = CurrentFile.Icon;
-			HoverText = CurrentFile.HoverText;
+			if (CurrentFile == null) {
+				Icon = "folder-recent;;document-open-recent";
+				HoverText = "Recent Documents";
+			} else {
+				Icon = CurrentFile.Icon;
+				HoverText = CurrentFile.HoverText;
+			}
 			QueueRedraw ();
 		}
 		
